/*
 * callbacks.c
 *
 * Copyright 2000, Chris Pinkham.
 * All Rights Reserved.
 */

#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include <gtk/gtk.h>
#include <gdk_imlib.h>
#include <sys/utsname.h>
#include <time.h>

#include "callbacks.h"
#include "interface.h"
#include "support.h"
#include "nix.h"

#include "gyach.h"
#include "images.h"
#include "commands.h"

extern SESSION session , *sess;

GtkWidget *favorites_window;
GtkWidget *froom_0;
GtkWidget *froom_1;
GtkWidget *froom_2;
GtkWidget *froom_3;
GtkWidget *froom_4;
GtkWidget *froom_5;
GtkWidget *froom_6;
GtkWidget *froom_7;
GtkWidget *froom_8;
GtkWidget *froom_9;
GtkWidget *file_sel;
GtkStyle  *about_style = NULL;

#define FILE_MSG_SAVE	"Save Current Text"
#define FILE_MSG_LOG	"Log To File"

int chatOut(SESSION *sess ,char *cmd);
int check_emote(SESSION *sess, char *emote, char *user );
int YahooTextCommand(SESSION *sess ,const char *cmd ,const char *txt);

void
on_b_send_clicked                      (GtkButton       *button,
                                        gpointer         user_data)
{
	char *text;

	text = strdup(gtk_entry_get_text(GTK_ENTRY(chat_entry)));
	gtk_entry_set_text(GTK_ENTRY(chat_entry), "");

	if ( ! strlen( text ))
		return;

	/* ok, we have something to send */
	chatOut( sess, text );
}


void
on_b_clear_clicked                     (GtkButton       *button,
                                        gpointer         user_data)
{
	gtk_entry_set_text(GTK_ENTRY(chat_entry), "");
}


void
on_window1_map                         (GtkWidget       *widget,
                                        gpointer         user_data)
{
	chat_window = widget;
}


void
on_chat_text_map                       (GtkWidget       *widget,
                                        gpointer         user_data)
{
	chat_text = widget;
}


void
on_chat_entry_map                      (GtkWidget       *widget,
                                        gpointer         user_data)
{
	chat_entry = widget;
}


void
on_chat_entry_activate                 (GtkEditable     *editable,
                                        gpointer         user_data)
{
	on_b_send_clicked( NULL, NULL );
}


void
on_emotions_select_row                 (GtkCList        *clist,
                                        gint             row,
                                        gint             column,
                                        GdkEvent        *event,
                                        gpointer         user_data)
{

}


void
on_emotions_map                        (GtkWidget       *widget,
                                        gpointer         user_data)
{
	chat_emotions = widget;

	read_emotions();
}


void
on_users_select_row                    (GtkCList        *clist,
                                        gint             row,
                                        gint             column,
                                        GdkEvent        *event,
                                        gpointer         user_data)
{
	gchar *useritem[1];
	gchar tmp_item[128];

	useritem[0] = tmp_item;

	gtk_clist_get_text( GTK_CLIST(chat_users), row, 1, useritem );

	if ( user_selected )
		free( user_selected );

	user_selected = strdup( useritem[0] );
}


void
on_users_map                           (GtkWidget       *widget,
                                        gpointer         user_data)
{
	chat_users = widget;
	gtk_clist_set_sort_column(GTK_CLIST(chat_users), 1 );
	/*
	gtk_clist_set_auto_sort(GTK_CLIST(chat_users), 0 ); 
	*/
}


gboolean
on_emotions_clicked                    (GtkWidget       *widget,
                                        GdkEventButton  *event,
                                        gpointer         user_data)
{
	gint row, column;
	gchar *listitem[1];
	gchar *useritem[1];
	gchar tmp_item[128];
	gchar tmp_item2[128];

	listitem[0] = tmp_item;
	useritem[0] = tmp_item2;

	if ( emote_window )
		return FALSE;

	if ((event->button == 1 && event->type == GDK_2BUTTON_PRESS) ||
		(event->button == 3 && event->type == GDK_BUTTON_PRESS))
	{
		if (!gtk_clist_get_selection_info(GTK_CLIST(chat_emotions),
				(gint) event->x, (gint) event->y, &row, &column))
		{
			return FALSE;
		}

		gtk_clist_unselect_all( GTK_CLIST(chat_emotions));
		gtk_clist_select_row( GTK_CLIST(chat_emotions), row, 0 );

		if ( gtk_clist_get_selectable( GTK_CLIST(chat_emotions), row )) {
			if (event->button == 1 && event->type == GDK_2BUTTON_PRESS) {
				/* double clicked send action */
				gtk_clist_get_text( GTK_CLIST(chat_emotions), row, 0,
					listitem );
				if ( user_selected ) {
					check_emote( sess, listitem[0], user_selected );
					gtk_clist_unselect_all( GTK_CLIST(chat_users));
					free( user_selected );
					user_selected = NULL;
				} else {
					check_emote( sess, listitem[0], "" );
				}
			} else {
				/* right clicked popup action window */
				emote_selected = row;
				gtk_menu_popup((GtkMenu *) emote_menu,
					NULL, NULL, NULL, NULL, 1, 0);

				/* old action was to send an emote on right click */
				/* now we do that on a subitem on this menu */
				/*
				gtk_clist_get_text( GTK_CLIST(chat_emotions), row, 0,
					listitem );
				if ( user_selected ) {
					check_emote( sess, listitem[0], user_selected );
				} else {
					check_emote( sess, listitem[0], "" );
				}
				*/
			}
		}
	}

	return FALSE;
}


void
on_users_unselect_row                  (GtkCList        *clist,
                                        gint             row,
                                        gint             column,
                                        GdkEvent        *event,
                                        gpointer         user_data)
{
	if ( user_selected )
		free( user_selected );
	user_selected = NULL;
}


void
on_connect_activate                    (GtkMenuItem     *menuitem,
                                        gpointer         user_data)
{

}


void
on_disconnect_activate                 (GtkMenuItem     *menuitem,
                                        gpointer         user_data)
{

}


void
on_quit_activate                       (GtkMenuItem     *menuitem,
                                        gpointer         user_data)
{
	sess->quit = 1;
	exit( 0 );
}


void
on_rooms1_activate                     (GtkMenuItem     *menuitem,
                                        gpointer         user_data)
{

}


void
on_room_list_activate                  (GtkMenuItem     *menuitem,
                                        gpointer         user_data)
{

}


void
on_favorites_activate                  (GtkMenuItem     *menuitem,
                                        gpointer         user_data)
{
	favorites_window = create_favorites();
	gtk_widget_show( favorites_window );

	if ( fav_room0 ) gtk_entry_set_text( GTK_ENTRY(froom_0), fav_room0 );
	if ( fav_room1 ) gtk_entry_set_text( GTK_ENTRY(froom_1), fav_room1 );
	if ( fav_room2 ) gtk_entry_set_text( GTK_ENTRY(froom_2), fav_room2 );
	if ( fav_room3 ) gtk_entry_set_text( GTK_ENTRY(froom_3), fav_room3 );
	if ( fav_room4 ) gtk_entry_set_text( GTK_ENTRY(froom_4), fav_room4 );
	if ( fav_room5 ) gtk_entry_set_text( GTK_ENTRY(froom_5), fav_room5 );
	if ( fav_room6 ) gtk_entry_set_text( GTK_ENTRY(froom_6), fav_room6 );
	if ( fav_room7 ) gtk_entry_set_text( GTK_ENTRY(froom_7), fav_room7 );
	if ( fav_room8 ) gtk_entry_set_text( GTK_ENTRY(froom_8), fav_room8 );
	if ( fav_room9 ) gtk_entry_set_text( GTK_ENTRY(froom_9), fav_room9 );
}


void
on_add_to_favorites_activate           (GtkMenuItem     *menuitem,
                                        gpointer         user_data)
{

}


void
on_help_activate                       (GtkMenuItem     *menuitem,
                                        gpointer         user_data)
{

}


void
on_about_activate                      (GtkMenuItem     *menuitem,
                                        gpointer         user_data)
{
	if ( ! about_box ) {
		if ( ! about_style ) {
			about_style = gtk_style_new();
			about_style->font = gdk_font_load("fixed");
		}

		about_box = create_about_box();
		gtk_widget_show( about_box );
	}
}


void
on_connection_activate                 (GtkMenuItem     *menuitem,
                                        gpointer         user_data)
{

}


void
on_user_menu_map                       (GtkWidget       *widget,
                                        gpointer         user_data)
{

}


void
on_profile_activate                    (GtkMenuItem     *menuitem,
                                        gpointer         user_data)
{
	gchar *listitem[1];
	gchar tmp_item[128];
	char  url[513];

	listitem[0] = tmp_item;

	if ( ! user_selected )
		return;

	display_profile( user_selected );
	return;

	snprintf( url, 512,
		"netscape -noraise -remote openURL\\(%s/%s,yahmini\\)",
		"http://profiles.yahoo.com", listitem[0] );

	system( url );
}


void
on_pm_activate                         (GtkMenuItem     *menuitem,
                                        gpointer         user_data)
{
	if ( ! user_selected )
		return;

	pm_window = create_pm_window();
	gtk_widget_show( pm_window );
}


void
on_add_to_friends_activate             (GtkMenuItem     *menuitem,
                                        gpointer         user_data)
{
	if ( ! user_selected )
		return;
}


void
on_ignore_activate                     (GtkMenuItem     *menuitem,
                                        gpointer         user_data)
{
	if ( ! user_selected )
		return;

	ignore_toggle( user_selected );
}


gboolean
on_users_clicked                       (GtkWidget       *widget,
                                        GdkEventButton  *event,
                                        gpointer         user_data)
{
	gint row, column;
	gchar *listitem[1];
	gchar tmp_item[128];

	listitem[0] = tmp_item;

	if ((event->button == 1 && event->type == GDK_2BUTTON_PRESS) ||
		(event->button == 3 && event->type == GDK_BUTTON_PRESS))
	{
		if (!gtk_clist_get_selection_info(GTK_CLIST(chat_users),
				(gint) event->x, (gint) event->y, &row, &column))
		{
			return FALSE;
		}

		gtk_clist_unselect_all( GTK_CLIST(chat_users));
		gtk_clist_select_row( GTK_CLIST(chat_users), row, 0 );

		if ( gtk_clist_get_selectable( GTK_CLIST(chat_users), row )) {
			gtk_clist_get_text( GTK_CLIST(chat_users), row, 1, listitem );
			if (event->button == 1 && event->type == GDK_2BUTTON_PRESS) {
				/* double clicked send PM */
				pm_window = create_pm_window();
				gtk_widget_show( pm_window );
			} else {
				/* right clicked popup user menu */
				gtk_menu_popup((GtkMenu *) chat_user_menu,
					NULL, NULL, NULL, NULL, 1, 0);
			}

		}
	}

	return FALSE;
}


void
on_pm_send_clicked                     (GtkButton       *button,
                                        gpointer         user_data)
{
	gchar *listitem[1];
	gchar tmp_item[128];
	char buf[1024];

	listitem[0] = tmp_item;

	snprintf( buf, 1023, "/tell %s %s", user_selected,
		gtk_entry_get_text(GTK_ENTRY(pm_entry)));

	chatOut( sess, buf );

	gtk_widget_destroy( pm_window );
}


void
on_pm_cancel_clicked                   (GtkButton       *button,
                                        gpointer         user_data)
{
	gtk_widget_destroy( pm_window );
}


void
on_pm_user_map                         (GtkWidget       *widget,
                                        gpointer         user_data)
{
	pm_user = widget;
}


void
on_pm_entry_map                        (GtkWidget       *widget,
                                        gpointer         user_data)
{
	pm_entry = widget;
}


void
on_pm_entry_activate                   (GtkEditable     *editable,
                                        gpointer         user_data)
{
	on_pm_send_clicked( NULL, NULL );
}


void
on_login_button_clicked                (GtkButton       *button,
                                        gpointer         user_data)
{
	valid_user = 1;
}


void
on_cancel_login_clicked                (GtkButton       *button,
                                        gpointer         user_data)
{
	username[0] = '\0';
	gtk_widget_destroy( login_window );

	valid_user = 1;
}


void
on_room_0_map                          (GtkWidget       *widget,
                                        gpointer         user_data)
{
	froom_0 = widget;
}


void
on_room_1_map                          (GtkWidget       *widget,
                                        gpointer         user_data)
{
	froom_1 = widget;
}


void
on_room_2_map                          (GtkWidget       *widget,
                                        gpointer         user_data)
{
	froom_2 = widget;
}


void
on_room_3_map                          (GtkWidget       *widget,
                                        gpointer         user_data)
{
	froom_3 = widget;
}


void
on_room_4_map                          (GtkWidget       *widget,
                                        gpointer         user_data)
{
	froom_4 = widget;
}


void
on_room_5_map                          (GtkWidget       *widget,
                                        gpointer         user_data)
{
	froom_5 = widget;
}


void
on_room_6_map                          (GtkWidget       *widget,
                                        gpointer         user_data)
{
	froom_6 = widget;
}


void
on_room_7_map                          (GtkWidget       *widget,
                                        gpointer         user_data)
{
	froom_7 = widget;
}


void
on_room_8_map                          (GtkWidget       *widget,
                                        gpointer         user_data)
{
	froom_8 = widget;
}


void
on_room_9_map                          (GtkWidget       *widget,
                                        gpointer         user_data)
{
	froom_9 = widget;
}


void
on_goto_fav0_clicked                   (GtkButton       *button,
                                        gpointer         user_data)
{
	YahooTextCommand(sess ,"join ", gtk_entry_get_text( GTK_ENTRY(froom_0)));
	gtk_widget_destroy( favorites_window );
}


void
on_goto_fav1_clicked                   (GtkButton       *button,
                                        gpointer         user_data)
{
	YahooTextCommand(sess ,"join ", gtk_entry_get_text( GTK_ENTRY(froom_1)));
	gtk_widget_destroy( favorites_window );
}


void
on_goto_fav2_clicked                   (GtkButton       *button,
                                        gpointer         user_data)
{
	YahooTextCommand(sess ,"join ", gtk_entry_get_text( GTK_ENTRY(froom_2)));
	gtk_widget_destroy( favorites_window );
}


void
on_goto_fav3_clicked                   (GtkButton       *button,
                                        gpointer         user_data)
{
	YahooTextCommand(sess ,"join ", gtk_entry_get_text( GTK_ENTRY(froom_3)));
	gtk_widget_destroy( favorites_window );
}


void
on_goto_fav4_clicked                   (GtkButton       *button,
                                        gpointer         user_data)
{
	YahooTextCommand(sess ,"join ", gtk_entry_get_text( GTK_ENTRY(froom_4)));
	gtk_widget_destroy( favorites_window );
}


void
on_goto_fav5_clicked                   (GtkButton       *button,
                                        gpointer         user_data)
{
	YahooTextCommand(sess ,"join ", gtk_entry_get_text( GTK_ENTRY(froom_5)));
	gtk_widget_destroy( favorites_window );
}


void
on_goto_fav6_clicked                   (GtkButton       *button,
                                        gpointer         user_data)
{
	YahooTextCommand(sess ,"join ", gtk_entry_get_text( GTK_ENTRY(froom_6)));
	gtk_widget_destroy( favorites_window );
}


void
on_goto_fav7_clicked                   (GtkButton       *button,
                                        gpointer         user_data)
{
	YahooTextCommand(sess ,"join ", gtk_entry_get_text( GTK_ENTRY(froom_7)));
	gtk_widget_destroy( favorites_window );
}


void
on_goto_fav8_clicked                   (GtkButton       *button,
                                        gpointer         user_data)
{
	YahooTextCommand(sess ,"join ", gtk_entry_get_text( GTK_ENTRY(froom_8)));
	gtk_widget_destroy( favorites_window );
}


void
on_goto_fav9_clicked                   (GtkButton       *button,
                                        gpointer         user_data)
{
	YahooTextCommand(sess ,"join ", gtk_entry_get_text( GTK_ENTRY(froom_9)));
	gtk_widget_destroy( favorites_window );
}


void
on_save_favs_clicked                   (GtkButton       *button,
                                        gpointer         user_data)
{
	free( fav_room0 ); free( fav_room1 ); free( fav_room2 );
	free( fav_room3 ); free( fav_room4 ); free( fav_room5 );
	free( fav_room6 ); free( fav_room7 ); free( fav_room8 );
	free( fav_room9 );
	
	fav_room0 = fav_room1 = fav_room2 = fav_room3 = fav_room4 = NULL;
	fav_room5 = fav_room6 = fav_room7 = fav_room8 = fav_room9 = NULL;

	fav_room0 = strdup( gtk_entry_get_text( GTK_ENTRY(froom_0)));
	fav_room1 = strdup( gtk_entry_get_text( GTK_ENTRY(froom_1)));
	fav_room2 = strdup( gtk_entry_get_text( GTK_ENTRY(froom_2)));
	fav_room3 = strdup( gtk_entry_get_text( GTK_ENTRY(froom_3)));
	fav_room4 = strdup( gtk_entry_get_text( GTK_ENTRY(froom_4)));
	fav_room5 = strdup( gtk_entry_get_text( GTK_ENTRY(froom_5)));
	fav_room6 = strdup( gtk_entry_get_text( GTK_ENTRY(froom_6)));
	fav_room7 = strdup( gtk_entry_get_text( GTK_ENTRY(froom_7)));
	fav_room8 = strdup( gtk_entry_get_text( GTK_ENTRY(froom_8)));
	fav_room9 = strdup( gtk_entry_get_text( GTK_ENTRY(froom_9)));

	write_config();
}


void
on_cancel_favs_clicked                 (GtkButton       *button,
                                        gpointer         user_data)
{
	gtk_widget_destroy( favorites_window );
}


gboolean
on_user_picture_button_press_event     (GtkWidget       *widget,
                                        GdkEventButton  *event,
                                        gpointer         user_data)
{

  return FALSE;
}


void
on_close_profile_clicked               (GtkButton       *button,
                                        gpointer         user_data)
{
	if ( ! user_selected )
		return;

	gtk_widget_hide( profile_window );
}


gboolean
on_homepage_button_press_event         (GtkWidget       *widget,
                                        GdkEventButton  *event,
                                        gpointer         user_data)
{

  return FALSE;
}


gboolean
on_coollink1_button_press_event        (GtkWidget       *widget,
                                        GdkEventButton  *event,
                                        gpointer         user_data)
{

  return FALSE;
}


gboolean
on_coollink2_button_press_event        (GtkWidget       *widget,
                                        GdkEventButton  *event,
                                        gpointer         user_data)
{

  return FALSE;
}


gboolean
on_coollink3_button_press_event        (GtkWidget       *widget,
                                        GdkEventButton  *event,
                                        gpointer         user_data)
{

  return FALSE;
}


void
on_emote_edit_activate                 (GtkMenuItem     *menuitem,
                                        gpointer         user_data)
{
	edit_emote();
}


void
on_emote_delete_activate               (GtkMenuItem     *menuitem,
                                        gpointer         user_data)
{
	gtk_clist_remove( GTK_CLIST(chat_emotions), emote_selected );
	emote_selected = -1;
	save_emotions();
}


void
on_emote_new_activate                  (GtkMenuItem     *menuitem,
                                        gpointer         user_data)
{
	gtk_clist_unselect_all( GTK_CLIST(chat_emotions));

	emote_selected = -1;
	edit_emote();
}


void
on_emote_send_activate                 (GtkMenuItem     *menuitem,
                                        gpointer         user_data)
{
	gchar *listitem[3];
	gchar emotion[128];
	gchar em_everyone[128];
	gchar em_user[128];

	listitem[0] = emotion;
	listitem[1] = em_everyone;
	listitem[2] = em_user;

	gtk_clist_get_text( GTK_CLIST(chat_emotions), emote_selected, 0,
		listitem );
	if ( user_selected ) {
		check_emote( sess, listitem[0], user_selected );
	} else {
		check_emote( sess, listitem[0], "" );
	}
}


void
on_emote_save_clicked                  (GtkButton       *button,
                                        gpointer         user_data)
{
	GtkWidget *tmp_widget;
	gchar *listitem[3];
	gchar tmp_item[12] = "tmp";
	gchar tmp_item2[12] = "tmp";
	gchar tmp_item3[12] = "tmp";

	listitem[0] = tmp_item;
	listitem[1] = tmp_item2;
	listitem[2] = tmp_item3;

	if ( emote_window ) {
		/* save the entry */

		if ( emote_selected == -1 ) {
			emote_selected = gtk_clist_insert(GTK_CLIST(chat_emotions), 0,
				listitem );
		}

		tmp_widget = lookup_widget( emote_window, "emote_name" );
		strcpy(	tmp_item, gtk_entry_get_text(GTK_ENTRY(tmp_widget)));
		tmp_item[0] = toupper( tmp_item[0] );
		gtk_clist_set_text(GTK_CLIST(chat_emotions), emote_selected, 0,
			tmp_item );
		tmp_widget = lookup_widget( emote_window, "emote_everyone" );
		gtk_clist_set_text(GTK_CLIST(chat_emotions), emote_selected, 1,
			gtk_entry_get_text(GTK_ENTRY(tmp_widget)));
		tmp_widget = lookup_widget( emote_window, "emote_user" );
		gtk_clist_set_text(GTK_CLIST(chat_emotions), emote_selected, 2,
			gtk_entry_get_text(GTK_ENTRY(tmp_widget)));

		gtk_clist_sort(GTK_CLIST(chat_emotions));

		emote_selected = -1;

		gtk_clist_unselect_all(GTK_CLIST(chat_emotions));

		save_emotions();

		/* now get rid of the window */
		on_emote_cancel_clicked( button, user_data );
	}
}


void
on_emote_cancel_clicked                (GtkButton       *button,
                                        gpointer         user_data)
{
	if ( emote_window ) {
		gtk_widget_hide( emote_window );
		gtk_widget_destroy( emote_window );
		emote_window = NULL;
	}
}



void
on_follow_activate                     (GtkMenuItem     *menuitem,
                                        gpointer         user_data)
{
	char buf[129];

	if ( user_selected ) {
		sprintf( buf, "/follow %s", user_selected );
		try_command( buf );
	}
}


void
on_about_box_map                       (GtkWidget       *widget,
                                        gpointer         user_data)
{
	struct utsname un;
	char buf[1024];
	GtkWidget *tmp_widget;

	snprintf(buf, sizeof(buf), "\nGyach v%s Copyright 2000 Chris Pinkham\n\n"
		"This software comes with No Warranty.\n\n"
		"This is free software and is distributed under the GPL.  You\n"
		"may redistribute it under certain conditions.  For more information\n"
		"please see the file COPYING for details.\n\n", VERSION );
	tmp_widget = lookup_widget( widget, "about_copy" );
	gtk_label_set_text( GTK_LABEL(tmp_widget), buf );

	uname(&un);
    snprintf(buf, sizeof(buf), "\n"
		"  Project Started ....... : July 2000\n"
		"  This Binary Compiled .. : " __DATE__ "\n"
		"  GTK+ Version .......... : %d.%d.%d\n"
		"  Currently Running on .. : %s %s [%s]\n"
		"  Author EMail .......... : %s\n"
		"  Web Page .............. : %s\n",
		gtk_major_version, gtk_minor_version, gtk_micro_version,
		un.sysname, un.release, un.machine, GYACH_EMAIL, GYACH_URL );

	tmp_widget = lookup_widget( widget, "about_info" );
	gtk_label_set_text( GTK_LABEL(tmp_widget), buf );
	gtk_widget_set_style( tmp_widget, about_style );
}


void
on_close_about_clicked                 (GtkButton       *button,
                                        gpointer         user_data)
{
	gtk_widget_destroy( about_box );

	about_box = NULL;
}


gboolean
on_chat_entry_key_press_event          (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data)
{
	if ( event->type == GDK_KEY_PRESS ) {
		/* 65289 == tab */
		/* 65293 == enter */
		/* 65362 == up arrow */
		/* 65364 == down arrow */
		/*
		printf( "keyval = %d\n", event->key.keyval ); fflush( stdout );
		*/

		/* if this is a tab key try to expand username */
		if ( event->key.keyval == 65289 ) {
			tab_complete_username();
			return( TRUE );
		}

		/* up arrow, scroll up to previous message */
		if ( event->key.keyval == 65362 ) {
			return( TRUE );
		}

		/* down arrow, scroll down to next message */
		if ( event->key.keyval == 65364 ) {
			return( TRUE );
		}
	}

	return FALSE;
}


void
on_save_current_text_activate          (GtkMenuItem     *menuitem,
                                        gpointer         user_data)
{
	gchar def_filename[255];

	if ( file_sel )
		return;

	file_sel = create_fileselection();

	if ( ! file_sel )
		return;

	gtk_widget_show( file_sel );

	sprintf( def_filename, "%s/.gyach/capture.txt", getenv("HOME") );

	gtk_file_selection_set_filename(GTK_FILE_SELECTION (file_sel),
	        def_filename );

	gtk_window_set_title( GTK_WINDOW(file_sel), FILE_MSG_SAVE );
}


void
on_log_to_file_activate                (GtkMenuItem     *menuitem,
                                        gpointer         user_data)
{
	GtkWidget *tmp_widget;
	gchar def_filename[255];

	/* see if we are closing the file */
	if ( capture_fp ) {
		fclose( capture_fp );
		capture_fp = NULL;

		free( capture_filename );
		capture_filename = NULL;

		tmp_widget = lookup_widget( chat_window, "log_to_file" );
		gtk_check_menu_item_set_active( GTK_CHECK_MENU_ITEM(tmp_widget), 0 );
		return;
	}

	if ( file_sel )
		return;

	file_sel = create_fileselection();

	if ( ! file_sel ) {
		tmp_widget = lookup_widget( chat_window, "log_to_file" );
		gtk_check_menu_item_set_active( GTK_CHECK_MENU_ITEM(tmp_widget), 0 );
		return;
	}

	gtk_widget_show( file_sel );

	sprintf( def_filename, "%s/.gyach/capture.log", getenv("HOME") );

	gtk_file_selection_set_filename(GTK_FILE_SELECTION (file_sel),
	        def_filename );

	gtk_window_set_title( GTK_WINDOW(file_sel), FILE_MSG_LOG );
}


void
on_status_here_activate                (GtkMenuItem     *menuitem,
                                        gpointer         user_data)
{
	if ( my_status )
		cmd_away( "\x0" );
}


void
on_status_be_right_back_activate       (GtkMenuItem     *menuitem,
                                        gpointer         user_data)
{
	if ( my_status != 1 )
		cmd_away( "\x1" );
}


void
on_status_busy_activate                (GtkMenuItem     *menuitem,
                                        gpointer         user_data)
{
	if ( my_status != 2 )
		cmd_away( "\x2" );
}


void
on_status_not_at_home_activate         (GtkMenuItem     *menuitem,
                                        gpointer         user_data)
{
	if ( my_status != 3 )
		cmd_away( "\x3" );
}


void
on_status_not_at_my_desk_activate      (GtkMenuItem     *menuitem,
                                        gpointer         user_data)
{
	if ( my_status != 4 )
		cmd_away( "\x4" );
}


void
on_status_not_in_the_office_activate   (GtkMenuItem     *menuitem,
                                        gpointer         user_data)
{
	if ( my_status != 5 )
		cmd_away( "\x5" );
}


void
on_status_on_the_phone_activate        (GtkMenuItem     *menuitem,
                                        gpointer         user_data)
{
	if ( my_status != 6 )
		cmd_away( "\x6" );
}


void
on_status_on_vacation_activate         (GtkMenuItem     *menuitem,
                                        gpointer         user_data)
{
	if ( my_status != 7 )
		cmd_away( "\x7" );
}


void
on_status_out_to_lunch_activate        (GtkMenuItem     *menuitem,
                                        gpointer         user_data)
{
	if ( my_status != 8 )
		cmd_away( "\x8" );
}


void
on_status_stepped_out_activate         (GtkMenuItem     *menuitem,
                                        gpointer         user_data)
{
	if ( my_status != 9 )
		cmd_away( "\x9" );
}


void
on_status_invisible_activate           (GtkMenuItem     *menuitem,
                                        gpointer         user_data)
{
	if ( my_status != 12 )
		cmd_away( "\xc" );
}


void
on_file_ok_button_clicked              (GtkButton       *button,
                                        gpointer         user_data)
{
	GtkWidget *tmp_widget;
	time_t time_now;

	if ( ! file_sel )
		return;

	capture_filename = strdup(
		gtk_file_selection_get_filename( GTK_FILE_SELECTION( file_sel )));

	if ( ! strcmp( GTK_WINDOW(file_sel)->title, FILE_MSG_SAVE )) {
		/* fixme, what about error opening */
		capture_text_to_file( capture_filename );
		free( capture_filename );
	} else if ( ! strcmp( GTK_WINDOW(file_sel)->title, FILE_MSG_LOG )) {
		capture_fp = fopen( capture_filename, "ab" );
		if ( capture_fp ) {
			time_now = time(NULL);
			fprintf( capture_fp, "%s", ctime(&time_now) );
			fprintf( capture_fp, "------------------------\n" );
		} else {
			/* fixme, how about an error message?? */
			tmp_widget = lookup_widget( chat_window, "log_to_file" );
			gtk_check_menu_item_set_active( GTK_CHECK_MENU_ITEM(tmp_widget), 0);
		}
	}

	gtk_widget_destroy( file_sel );
	file_sel = NULL;
}


void
on_file_cancel_button_clicked          (GtkButton       *button,
                                        gpointer         user_data)
{
	GtkWidget *tmp_widget;

	if ( ! strcmp( GTK_WINDOW(file_sel)->title, FILE_MSG_LOG )) {
		tmp_widget = lookup_widget( chat_window, "log_to_file" );
		gtk_check_menu_item_set_active( GTK_CHECK_MENU_ITEM(tmp_widget), 0 );
	}

	gtk_widget_hide( file_sel );
	gtk_widget_destroy( file_sel );
	file_sel = NULL;
}


void
on_setup_activate                      (GtkMenuItem     *menuitem,
                                        gpointer         user_data)
{
	GtkWidget *tmp_widget;

	if ( setup_window )
		return;

	setup_window = create_setup_window();

	/* show the correct settings */
	tmp_widget = lookup_widget( setup_window, "auto_login" );

	tmp_widget = lookup_widget( setup_window, "auto_away_time" );
	gtk_spin_button_set_value( GTK_SPIN_BUTTON( tmp_widget ),
		(float)auto_away );

	tmp_widget = lookup_widget( setup_window, "blended_colors" );
	gtk_toggle_button_set_active(
		&(GTK_CHECK_BUTTON(tmp_widget)->toggle_button), use_blended_colors );

	tmp_widget = lookup_widget( setup_window, "packet_debugging" );
	gtk_toggle_button_set_active(
		&(GTK_CHECK_BUTTON(tmp_widget)->toggle_button), debug_packets );

	tmp_widget = lookup_widget( setup_window, "auto_away" );
	tmp_widget = lookup_widget( setup_window, "custom_away_message" );
	tmp_widget = lookup_widget( setup_window, "pm_brings_back" );
	tmp_widget = lookup_widget( setup_window, "limit_buffer_size" );
	tmp_widget = lookup_widget( setup_window, "buffer_size" );

	tmp_widget = lookup_widget( setup_window, "show_colors" );
	gtk_toggle_button_set_active(
		&(GTK_CHECK_BUTTON(tmp_widget)->toggle_button), use_my_colors );

	tmp_widget = lookup_widget( setup_window, "show_fonts" );
	gtk_toggle_button_set_active(
		&(GTK_CHECK_BUTTON(tmp_widget)->toggle_button), use_my_font );

	tmp_widget = lookup_widget( setup_window, "show_html" );
	tmp_widget = lookup_widget( setup_window, "show_statuses" );
	tmp_widget = lookup_widget( setup_window, "profile_viewer" );
	tmp_widget = lookup_widget( setup_window, "ignore_on_mults" );
	
	/* finally show the window */
	gtk_widget_show( setup_window );
}


void
on_save_setup_clicked                  (GtkButton       *button,
                                        gpointer         user_data)
{
	GtkWidget *tmp_widget;

	if ( ! setup_window )
		return;

	/* gather & save the settings */
	tmp_widget = lookup_widget( setup_window, "auto_login" );

	tmp_widget = lookup_widget( setup_window, "auto_away_time" );
	auto_away = gtk_spin_button_get_value_as_int(
		GTK_SPIN_BUTTON( tmp_widget ));

	tmp_widget = lookup_widget( setup_window, "blended_colors" );
	use_blended_colors = gtk_toggle_button_get_active(
		&(GTK_CHECK_BUTTON(tmp_widget)->toggle_button));

	tmp_widget = lookup_widget( setup_window, "packet_debugging" );
	debug_packets = gtk_toggle_button_get_active(
		&(GTK_CHECK_BUTTON(tmp_widget)->toggle_button));

	tmp_widget = lookup_widget( setup_window, "auto_away" );
	tmp_widget = lookup_widget( setup_window, "custom_away_message" );
	tmp_widget = lookup_widget( setup_window, "pm_brings_back" );
	tmp_widget = lookup_widget( setup_window, "limit_buffer_size" );
	tmp_widget = lookup_widget( setup_window, "buffer_size" );

	tmp_widget = lookup_widget( setup_window, "show_colors" );
	use_my_colors = gtk_toggle_button_get_active(
		&(GTK_CHECK_BUTTON(tmp_widget)->toggle_button));

	tmp_widget = lookup_widget( setup_window, "show_fonts" );
	use_my_font = gtk_toggle_button_get_active(
		&(GTK_CHECK_BUTTON(tmp_widget)->toggle_button));

	tmp_widget = lookup_widget( setup_window, "show_html" );
	tmp_widget = lookup_widget( setup_window, "show_statuses" );
	tmp_widget = lookup_widget( setup_window, "profile_viewer" );
	tmp_widget = lookup_widget( setup_window, "ignore_on_mults" );

	write_config();

	/* destroy the window */
	gtk_widget_destroy( setup_window );
	setup_window = NULL;
}


void
on_cancel_setup_clicked                (GtkButton       *button,
                                        gpointer         user_data)
{
	if ( ! setup_window )
		return;

	gtk_widget_destroy( setup_window );
	setup_window = NULL;
}

